bayespy.inference.vmp.transformations.RotationOptimizer.rotate
==============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotationOptimizer.rotate